# Generated by Django 3.2.11 on 2022-04-15 14:47

from django.db import migrations

import edc_action_item.models.action_model_mixin
import edc_sites.models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0004_auto_20220414_1741"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="rx",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
            ],
        ),
    ]
