{% extends "admin/base_site.html" %}

{% load static %}

{% block content %}
  <div class="container">
    <div class="col-sm-3"></div>
    <div class="col-sm-6">
      <div class="panel panel-default">
        <div class="panel-heading">Select a label configuration</div>
        <div class="panel-body">
          <form class="form-horizontal" action="{{ url }}" method="post" onSubmit="document.getElementById('submit').disabled=true;">
            {% csrf_token %}
            <div class="form-group">
              <label class="control-label col-sm-2" for="phrase">Label configuration name:</label>
              <div class="col-sm-10">
                <input type="text" class="form-control" id="label_configuration_name" name="phrase" placeholder="enter a label configuration name" value="{{ label_configuration_name|default:'' }}" required>
              </div>
            </div>
            <button type="submit" class="btn btn-default" name="submit" id="submit">Submit</button>
            <a class="btn btn-default" href="{{return_to_changelist_url}}">Done</a>
          </form>
        </div>
      </div>
    </div>
    <div class="col-sm-3"></div>
  </div>
{% endblock content %}
